@@ -24,6 +24,7 @@
 #include "game.h"
 #include "convert.h"
 #include "badguess.h"
+#include "utils.h"
 #include "log.h"
 
 #include "timeout.h"
@@ -60,11 +61,8 @@ Boolean UseThisKanji(int kanjinum)
 {
 	TRANSLATION kanji = translations[kanjinum];
 
-	
-	if(useUsefile)
-	{
-		if(InUsefile(kanjinum) == False)
-		{
+	if(useUsefile){
+		if(InUsefile(kanjinum) == False){
 			return False;
 		}
 	}
@@ -142,8 +140,7 @@ void CountKanji()
 	int knum;
 	numberofkanji=0;
 
-	for(knum=lowestkanji; knum<=highestkanji;knum++)
-	{
+	for(knum=lowestkanji; knum<=highestkanji;knum++){
 		ktrans = translations[knum];
 		if(ktrans == NULL)
 			continue;
@@ -161,8 +158,7 @@ void TallyWrong()
 {
 	int wcount=0;
 	int kcount=0;
-	for(kcount=lowestkanji; kcount<=highestkanji; kcount++)
-	{
+	for(kcount=lowestkanji; kcount<=highestkanji; kcount++){
 		if(translations[kcount]==NULL)
 			continue;
 		if(translations[kcount]->incorrect>0)
@@ -176,8 +172,7 @@ void TallyWrong()
 void ClearMissed()
 {
 	int kcount;
-	for(kcount=lowestkanji; kcount<=highestkanji; kcount++)
-	{
+	for(kcount=lowestkanji; kcount<=highestkanji; kcount++)	{
 		if(translations[kcount]==NULL)
 			continue;
 		translations[kcount]->incorrect=0;
@@ -198,10 +193,8 @@ TRANSLATION pickkanji()
 
 	rand_kanji = lrand48()%numberofkanji;
 
-	for(count=lowestkanji;count<=highestkanji;count++)
-	{
-		if(UseThisKanji(count))
-		{
+	for(count=lowestkanji;count<=highestkanji;count++){
+		if(UseThisKanji(count))	{
 		      rand_kanji--;
 		      if(rand_kanji <0)
 			  return translations[count];
@@ -232,8 +225,7 @@ TRANSLATION pickincorrect()
 	TRANSLATION currentpick=lastpicked;
 	int count;
 
-	if(numberincorrect==0)
-	{
+	if(numberincorrect==0){
 		puts("Internal Error.. pickincorrect called when no incorrect stored");
 		return pickkanji();
 	}
@@ -251,10 +243,9 @@ TRANSLATION pickincorrect()
 			currentpick=translations[count];
 
 		} while(!UseThisKanji(count));
-		if(translations[count] == lastpicked)
-		{
-			if(numberincorrect>1)
-			{ /* why didnt we hit a second incorrect one? */
+		if(translations[count] == lastpicked){
+			if(numberincorrect>1){
+				/* why didnt we hit a second incorrect one? */
 				setstatus("Internal error picking repeat");
 			}
 			return lastpicked;
@@ -284,14 +275,11 @@ TRANSLATION picktruevalue()
 	int currentpick;
 	TRANSLATION ret_val = lastpicked;
 
-	if(!showinorder)
-	{
+	if(!showinorder){
 		/* Should we repeat a kanji they missed earlier? */
 		/* First check if they have missed any */
-		if(numberincorrect>0)
-		{
-			if(lrand48()%REPEATFRACTION == 0)
-			{
+		if(numberincorrect>0){
+			if(lrand48()%REPEATFRACTION == 0){
 				/* repeat what user missed  */
 				/*ret_val = pickincorrect();*/
 				ret_val=GetRepeat();
@@ -305,8 +293,7 @@ TRANSLATION picktruevalue()
 		/* This also catches the case where we repeat one
 		 * they missed, and it is the current one showing
 		 */
-		while (ret_val == lastpicked)
-		{
+		while (ret_val == lastpicked){
 			ret_val = pickkanji();
 		}
 
@@ -321,8 +308,7 @@ TRANSLATION picktruevalue()
 
 		currentpick =lowestkanji;
 
-		while(lastpicked != translations[currentpick])
-		{
+		while(lastpicked != translations[currentpick]){
 			currentpick++;
 		}
 		
@@ -378,8 +364,7 @@ void guessvalue(int guess)
 	if(guess == truevalue){
 		ClearCheat();
 		setstatus("Correct! Now try THIS one...");
-		switch(kanjiP->incorrect)
-		{
+		switch(kanjiP->incorrect){
 			case 0:
 				break;
 			case 1:
@@ -404,8 +389,7 @@ void guessvalue(int guess)
 	 */
 	Beep();
 	setstatus("Incorrect.");
-	if(guess != -1)
-	{
+	if(guess != -1){
 		markasmissed(kanjiP);
 	}
 
@@ -459,8 +443,7 @@ void setenglabel(Widget widget,TRANSLATION trans)
 
 void setkanalabel(Widget widget,TRANSLATION trans)
 {
-	if(romajiswitch ==1)
-	{
+	if(romajiswitch ==1){
 		char stringbuff[MAXROMAJI+1];
 		/*translate all kana into romaji */
 		/* translate to buffer, then set widget string*/
@@ -479,8 +462,7 @@ void setkanalabel(Widget widget,TRANSLATION trans)
 		      XtNlabel,stringbuff,
 		      NULL);
 		
-	} else
-	{
+	} else {
 	/* This needs to be done separately? */
 		XtVaSetValues(widget,
 		     XtNencoding,XawTextEncodingChar2b,
@@ -500,8 +482,7 @@ void setkanalabel(Widget widget,TRANSLATION trans)
 
 void printquestion()
 {
-	switch(questionmode)
-	{
+	switch(questionmode) {
 		case GUESS_ENGLISH:
 			setenglabel(questionWidget,values[truevalue]);
 			break;
@@ -528,16 +509,14 @@ void printallchoices()
 {
 	int i;
 
-	for(i=0;i<NUMBEROFCHOICES;i++)
-	{
+	for(i=0;i<NUMBEROFCHOICES;i++) {
 		/* Used to call UnhighlightButton() on each, to make sure
 		 * 'cheat' effect went away.
 		 * Now, guessvalue() calls ClearCheat() if correct
 		 * value has been clicked on.
 		 */
 
-		switch(choicesmode)
-		{
+		switch(choicesmode) {
 			case GUESS_ENGLISH:
 				setenglabel(choicesWidgets[i],values[i]);
 				break;
@@ -579,10 +558,8 @@ void SetupGuess()
 	truevalue = lrand48() %NUMBEROFCHOICES;
 
 	/* Now randomly assign characters for each choice button */
-	for(valuecount=0;valuecount<NUMBEROFCHOICES;valuecount++)
-	{
-		if(valuecount == truevalue)
-		{
+	for(valuecount=0;valuecount<NUMBEROFCHOICES;valuecount++){
+		if(valuecount == truevalue){
 			values[valuecount] = picktruevalue();
 		} else {
 			values[valuecount] = pickkanji();
