@@ -1,3 +1,6 @@
+#ifndef _GAME_H
+#define _GAME_H
+
 extern TRANSLATION lastpicked;
 extern int truevalue;
 extern int numberincorrect;
@@ -38,3 +41,5 @@ extern Boolean UseThisKanji(int kanjinum);
 /* This function is declared in externs.h, but should be here, sort of
 *    extern void setstatus(char *);
 */
+
+#endif /* _GAME_H */
