@@ -36,6 +36,7 @@ char usefilename[100];
 
 Atom wm_message,delete_message;
 
+
 /*
  * This array has "fallback resources", in case
  * the normal "KDrill" resource file is not present.
@@ -61,6 +62,7 @@ static char *fallback[] = {
 	"KDrill.usefile:	.kanjiusefile", 
 	DICTLOCATION,	/* change this value in Imakefile !!*/
 	EDICTLOCATION,	/* change this value in Imakefile !!*/
+	RADLOCATION,	/* change this value in Imakefile !!*/
 	"KDrill.kanjifont:	-jis-*--24*jisx0208*",
 	"KDrill.smallkanji:	-jis-*--16*jisx0208*",
 	"KDrill.englishfont:	fixed",
@@ -84,6 +86,7 @@ static XrmOptionDescRec optionDescList[] = {
 	{"-nousefile",  ".nousefile",	XrmoptionNoArg, "1"},
 	{"-kdictfile",	".kdictfile",	XrmoptionSepArg,(caddr_t) NULL},
 	{"-edictfile",	".edictfile",	XrmoptionSepArg,(caddr_t) NULL},
+	{"-radkfile",	".radkfile",	XrmoptionSepArg,(caddr_t) NULL},
 	{"-englishfont",".englishfont",	XrmoptionSepArg,(caddr_t) NULL},
 	{"-kanjifont",	".kanjifont",	XrmoptionSepArg,(caddr_t) NULL},
 	{"-smallkanji",	".smallkanji",	XrmoptionSepArg,(caddr_t) NULL},
@@ -261,6 +264,9 @@ void setup_deletewindow(Widget winwidget)
 
 }
 
+#ifndef _POSIX_PATH_MAX
+#define _POSIX_PATH_MAX 1024
+#endif
 
 /* If we have the appropriate functions (X11R6?)
  * load up our own special user-specific xresources file
