@@ -8,9 +8,9 @@
 #include <Xaw/Command.h>
 #include <Xaw/Label.h>
 #include <Xaw/Form.h>
-#include <Xaw/Paned.h>
 #include <Xaw/Box.h>
 #include <Xaw/AsciiText.h>
+#include <Xaw/Paned.h> /* See comment around MakeSpecialForms */
 
 #include "defs.h"
 #include "externs.h"
@@ -19,6 +19,7 @@
 #include "options.h"
 #include "search.h"
 #include "searchwidgets.h"
+#include "strokesearch.h"
 #include "learn.h"
 #include "utils.h"
 #include "multikanji.h"
@@ -26,7 +27,7 @@
 #include "log.h"
 #include "timeout.h"
 
-Widget toplevel,form;
+Widget toplevel,mainform;
 
 XFontStruct *largekfont;
 XFontStruct *smallkfont;
@@ -173,17 +174,14 @@ void DescribeCurrent(TRANSLATION kanji)
 {
 	int kindex;
 
-	if(kanji->kanji == NULL)
-	{
+	if(kanji->kanji == NULL) {
 		kindex = 0;
-	} else
-	{
+	} else {
 		kindex = kanji->kanji[0].byte1;
 		kindex = kindex <<8;
 		kindex |= kanji->kanji[0].byte2;
 	}
-	if(kindex == NOKANJI)
-	{
+	if(kindex == NOKANJI) {
 		kindex = 0;
 	}
 			
@@ -215,9 +213,7 @@ void JumpToKanji(Widget w,XEvent *event,String *params,Cardinal *num_parags)
 		} 
 
 		kindex = getclosestindex(kindex);
-	}
-	else
-	{
+	} else {
 		if(kindex <1){
 			setstatus("negative frequencies do not occur");
 			/*	SetWidgetNumberval(w,values[truevalue]);*/
@@ -249,27 +245,41 @@ void MakeSpecialForms(Widget parent){
 
 	/* We try to set resource so that we will be happy  with EITHER
 	 * a Paned parent, or a Form parent.
+	 *
+	 * Note that if the parent is PanedWidget, these forms will
+	 * all be forcibly resized and stretched, ignoring
+	 * XawChainXXX
 	 */
 
 
-	kanjiform = XtVaCreateManagedWidget("kanjiform",formWidgetClass, form,
+	kanjiform = XtVaCreateManagedWidget("kanjiform",formWidgetClass, mainform,
 			XtNshowGrip, False,
-			XtNresizeToPreferred, True,
-
+			XtNright, XawChainRight,
+			XtNleft,  XawChainLeft,
+			XtNtop,XawChainBottom,
+			XtNbottom,XawChainBottom,
 			NULL);
 	englishform = XtVaCreateManagedWidget("englishform",formWidgetClass,
-				form,
-		XtNfromVert,kanjiform,
-		XtNvertDistance,10,
+			mainform,
+			XtNfromVert,kanjiform,
+			XtNvertDistance,10,
 			XtNshowGrip, False,
-			XtNresizeToPreferred, True,
-				NULL);
-	buttonform = XtVaCreateManagedWidget("buttonform",formWidgetClass,form,
-		     XtNfromVert,englishform,
-		     XtNvertDistance,15,
+			XtNright, XawChainRight,
+			XtNleft,  XawChainLeft,
+			XtNtop,XawChainBottom,
+			XtNbottom,XawChainBottom,
+			NULL);
+	buttonform = XtVaCreateManagedWidget(
+			"buttonform",formWidgetClass,mainform,
+			XtNfromVert,englishform,
+			XtNvertDistance,15,
 			XtNshowGrip, False,
 			XtNskipAdjust, True,
-					    NULL);
+			XtNright, XawChainLeft,
+			XtNleft,  XawChainLeft,
+			XtNtop,XawChainBottom,
+			XtNbottom,XawChainBottom,
+			NULL);
 
 }
 
@@ -287,20 +297,22 @@ Widget MakeCurrent(Widget parent,Widget fromvert){
 	currentkanjiForm = XtVaCreateManagedWidget(
 			"curkanjiForm",boxWidgetClass,parent,
 			/*XtNright,XawChainRight,XtNleft,XawChainRight,*/
-			XtNleft,XawChainLeft,
-			XtNresize,False,
+			XtNtop,XawChainTop, XtNbottom,XawChainTop,
+			XtNleft, XawChainLeft, XtNright,XawChainLeft,
 			XtNfromVert,fromvert,
 			XtNorientation,XtEhorizontal,
 			NULL);
 	gradelabel = XtVaCreateManagedWidget(
 			"currgradelabel",labelWidgetClass,currentkanjiForm,
 			XtNlabel,"G:",
+			XtNtop,XawChainTop,
+			XtNbottom,XawChainTop,
 			XtNborderWidth,0,
 			NULL);
 	currentkanjiGrade = XtVaCreateManagedWidget(
 			"curkanjiGrade",asciiTextWidgetClass,currentkanjiForm,
-			XtNwidth,INPUTWIDTH,
-			XtNstring,"     ",
+			XtNwidth,30, /* match search window */
+			XtNstring,"  ",
 			XtNdisplayCaret,False,
 			NULL);
 	freqlabel = XtVaCreateManagedWidget(
@@ -353,8 +365,13 @@ void MakeQuestionWidget(){
 	XtAccelerators Accel;
 
 	if(kanjiform == NULL){
-	kanjiform = XtVaCreateManagedWidget("kanjiform",formWidgetClass, form,
-			XtNright,XawChainRight,
+		/* normally made in MakeSpecialForms() */
+		kanjiform = XtVaCreateManagedWidget(
+			"kanjiform",formWidgetClass, mainform,
+			XtNright, XawChainRight,
+			XtNleft,  XawChainLeft,
+			XtNtop,XawChainBottom,
+			XtNbottom,XawChainBottom,
 			NULL);
 	}
 
@@ -367,6 +384,9 @@ void MakeQuestionWidget(){
 			XtNwidth,FULLWIDTH,
 			XtNencoding,XawTextEncodingChar2b,
 			XtNfont,largekfont,
+			XtNtop,XawChainTop,
+			XtNbottom,XawChainTop,
+			XtNleft, XawChainLeft, XtNright,XawChainRight,
 			NULL);
 
 #ifdef USE_OKU
@@ -375,6 +395,8 @@ void MakeQuestionWidget(){
 			XtNlabel,"       ",
 			XtNencoding,XawTextEncodingChar2b,
 			XtNfont,smallkfont,
+			XtNtop,XawChainTop,
+			XtNbottom,XawChainTop,
 			XtNjustify,XtJustifyLeft,
 			XtNwidth,KANJIWIDTH * NUMBEROFCHOICES +
 					   (NUMBEROFCHOICES *5),
@@ -388,6 +410,9 @@ void MakeQuestionWidget(){
 			"missedlabel",labelWidgetClass,kanjiform,
 			XtNfromVert, questionWidget,
 			XtNfromHoriz, currentkanjiForm,
+			XtNtop,XawChainTop,
+			XtNbottom,XawChainTop,
+			XtNleft, XawChainLeft, XtNright,XawChainLeft,
 			XtNlabel,"missed",
 			XtNborderWidth,0,
 			/* nasty hardcode.. */
@@ -397,6 +422,9 @@ void MakeQuestionWidget(){
 			"missedkanji",asciiTextWidgetClass,kanjiform,
 			XtNfromVert, questionWidget,
 			XtNfromHoriz, tmplabel,
+			XtNtop,XawChainTop,
+			XtNbottom,XawChainTop,
+			XtNleft, XawChainLeft, XtNright,XawChainLeft,
 			XtNwidth, INPUTWIDTH/2,
 			XtNdisplayCaret,False,
 			XtNvertDistance, 10,
@@ -415,11 +443,16 @@ void MakeChoicesButtons(){
 
 
 	if(englishform==NULL) {
-	englishform = XtVaCreateManagedWidget("englishform",formWidgetClass,
-				form,
-				XtNfromVert,kanjiform,
-				XtNvertDistance,5,
-				NULL);
+		/* See also MakeSpecialWidgets() */
+		englishform = XtVaCreateManagedWidget(
+			"englishform",formWidgetClass, mainform,
+			XtNfromVert,kanjiform,
+			XtNvertDistance,5,
+			XtNright, XawChainRight,
+			XtNleft,  XawChainLeft,
+			XtNtop,XawChainBottom,
+			XtNbottom,XawChainBottom,
+			NULL);
 	}
 
 	for(i=0;i<NUMBEROFCHOICES;i++){
@@ -432,6 +465,8 @@ void MakeChoicesButtons(){
 			XtNwidth,FULLWIDTH,
 			XtNright,XawChainRight,
 			XtNleft,XawChainLeft,
+			XtNtop,XawChainTop,
+			XtNbottom,XawChainTop,
 			XtNfont,largekfont,
 			XtNvertDistance,10,
 			XtNshapeStyle,XawShapeRoundedRectangle,
@@ -441,8 +476,8 @@ void MakeChoicesButtons(){
 		   choicesWidgets[i]=XtVaCreateWidget(
 			labl,commandWidgetClass,englishform,
 			XtNwidth,FULLWIDTH,
-			XtNright,XawChainRight,
-			XtNleft,XawChainLeft,
+			XtNright,XawChainRight,	XtNleft,XawChainLeft,
+			XtNtop,XawChainTop, XtNbottom,XawChainTop,
 			XtNfont,largekfont,
 			XtNfromVert,choicesWidgets[i-1],
 			XtNshapeStyle,XawShapeRoundedRectangle,
@@ -462,19 +497,27 @@ void MakeButtons(){
 	Widget w[7];
 
 	if(buttonform==NULL){
-	buttonform = XtVaCreateManagedWidget("buttonform",formWidgetClass,form,
-					     XtNfromVert,englishform,
-					     XtNvertDistance,15,
-					    NULL);
+		/* See also MakeSpecialForms(). sigh */
+		buttonform = XtVaCreateManagedWidget(
+			"buttonform",formWidgetClass,mainform,
+			XtNfromVert,englishform,
+			XtNvertDistance,15,
+			XtNright, XawChainLeft,	XtNleft,  XawChainLeft,
+			XtNtop,XawChainBottom,	XtNbottom,XawChainBottom,
+			NULL);
 	}
 
 	w[0] = XtVaCreateWidget("quit",commandWidgetClass,buttonform,
 			XtNlabel,"quit",
 			XtNshapeStyle,XawShapeEllipse,
+			XtNleft, XawChainLeft, XtNright,XawChainLeft,
+			XtNtop,XawChainBottom, XtNbottom,XawChainBottom,
 			NULL);
 
 	w[1] = XtVaCreateWidget("cheat",commandWidgetClass,buttonform,
 			XtNfromHoriz,w[0],
+			XtNleft, XawChainLeft, XtNright,XawChainLeft,
+			XtNtop,XawChainBottom, XtNbottom,XawChainBottom,
 			NULL);
 
 	w[2]= XtVaCreateManagedWidget("back",commandWidgetClass,
@@ -482,12 +525,16 @@ void MakeButtons(){
 			XtNlabel,"prev. char",
 			XtNfromHoriz,w[1],
 			/*XtNshapeStyle,XawShapeEllipse,*/
+			XtNleft, XawChainLeft, XtNright,XawChainLeft,
+			XtNtop,XawChainBottom, XtNbottom,XawChainBottom,
 			NULL);
 
 	w[3]= XtVaCreateManagedWidget("log",commandWidgetClass,
 			buttonform,
 			XtNlabel,"Log",
 			XtNfromHoriz,w[2],
+			XtNleft, XawChainLeft, XtNright,XawChainLeft,
+			XtNtop,XawChainBottom, XtNbottom,XawChainBottom,
 			/*XtNshapeStyle,XawShapeEllipse,*/
 			NULL);
 
@@ -495,6 +542,8 @@ void MakeButtons(){
 			buttonform,
 			XtNlabel,"options",
 			XtNfromHoriz,w[3],
+			XtNleft, XawChainLeft, XtNright,XawChainLeft,
+			XtNtop,XawChainBottom, XtNbottom,XawChainBottom,
 			XtNshapeStyle,XawShapeEllipse,
 			NULL);
 
@@ -502,12 +551,16 @@ void MakeButtons(){
 			buttonform,
 			XtNlabel,"Search",
 			XtNfromHoriz,w[4],
+			XtNleft, XawChainLeft, XtNright,XawChainLeft,
+			XtNtop,XawChainBottom, XtNbottom,XawChainBottom,
 			XtNshapeStyle,XawShapeEllipse,
 			NULL);
 	w[6]= XtVaCreateManagedWidget("learn",commandWidgetClass,
 			buttonform,
 			XtNlabel,"Learn",
 			XtNfromHoriz,w[5],
+			XtNleft, XawChainLeft, XtNright,XawChainLeft,
+			XtNtop,XawChainBottom, XtNbottom,XawChainBottom,
 			XtNshapeStyle,XawShapeEllipse,
 			NULL);
 
@@ -520,6 +573,8 @@ void MakeButtons(){
 			XtNborderWidth,2,
 			XtNvertDistance,STATUSDISTANCE,
 			XtNfromVert,w[0],
+			XtNleft, XawChainLeft, XtNright,XawChainLeft,
+			XtNtop,XawChainBottom, XtNbottom,XawChainBottom,
 		      NULL);
 
 	XtAddCallback(w[0],XtNcallback,quit,NULL);
@@ -765,15 +820,30 @@ void quitaction(Widget w, XEvent * e, String *p, Cardinal *c)
 	quit(NULL, NULL, NULL);
 }
 
+
+/* deliberately a "nop". used primarily to make the RETURN key
+ * do nothing, when we want to disable it.
+ */
+void do_nothing(Widget w, XEvent * e, String *p, Cardinal *c)
+{
+	return;
+}
+
+/* Different widgets may have different "Accelerator" tables,
+ * parsed by 
+ * but all of them have to hook through this shared Actions list
+ */
 static XtActionsRec kdrillActionList[] = {
 	{ "quit",		quitaction},
 	{ "update-frequency",	UpdateFrequency},
 	{ "update-timeout",	UpdateTimeout},
 	{ "do-find",		DoFind},
+	{ "stroke-search",	DoStrokeSearch}, /* ignore warning*/
 	{ "jump-to-kanji",	JumpToKanji},
 	{ "guess-meaning",	Guessvalue},
 	{ "Accelerator",	Accelerator},
 	{ "delete-window",	delete_callback},
+	{ "do-nothing",		do_nothing},
 };
 	
 XtAccelerators AllAccel;
@@ -796,15 +866,18 @@ void MakeWidgets(){
 		but it makes things easier for now.
 	*/
 
-#ifdef USEFORMFORTOP
-	form = XtVaCreateManagedWidget("kdrill",formWidgetClass,
+#ifdef USEFORMFORTOP /* not currently used */
+	mainform = XtVaCreateManagedWidget("kdrill",formWidgetClass,
 					   toplevel,
 			XtNvSpace,16,
 			XtNhSpace,10,
 			NULL);
 #else
+	/* Note: This automatically stretches out the widgets to be
+	 * the full width of the window
+	 */
 
-	form = XtVaCreateManagedWidget("kdrill",panedWidgetClass,
+	mainform = XtVaCreateManagedWidget("kdrill",panedWidgetClass,
 					   toplevel,
 			NULL);
 #endif
@@ -814,10 +887,10 @@ void MakeWidgets(){
 	XtAppAddActions(Context,kdrillActionList,XtNumber(kdrillActionList) );
 	AllAccel = XtParseAcceleratorTable(guessAccel);
 
-	/*XtOverrideTranslations(form,AllAccel);*/
-	XtAugmentTranslations(form,AllAccel);
+	/*XtOverrideTranslations(mainform,AllAccel);*/
+	XtAugmentTranslations(mainform,AllAccel);
 
-	MakeSpecialForms(form);
+	MakeSpecialForms(mainform);
 
 	MakeQuestionWidget();
 	MakeChoicesButtons();
